@@ -22,12 +22,15 @@ fn report_errors(errors: Vec<InputParseError>) -> TokenStream {
         InputParseError::VariantHasNamedFields(span) => {
             quote_spanned!(span => compile_error!("into_variant does not support named fields");)
         }
-        InputParseError::VariantHasNoFields(span) => {
-            quote_spanned!(span => compile_error!("into_variant requires variants to have a single field; no fields found");)
-        }
         InputParseError::VariantHasMultipleFields(span) => {
             quote_spanned!(span => compile_error!("into_variant requires variants to have a single field; multiple fields found");)
         }
+        InputParseError::VariantHasComplexType(span) => {
+            quote_spanned!(span => compile_error!("into_variant does not support complex types; fields must be a simple struct or enum");)
+        }
+        InputParseError::UnexpectedAnnotation(span) => {
+            quote_spanned!(span => compile_error!("Unexpected annotation: only `into_variant(skip)` is supported");)
+        }
     });
 
     quote! {
