@@ -1,7 +1,7 @@
 use proc_macro2::{Ident, TokenStream};
 use quote::quote;
 
-use crate::input::{InputEnum, Variant, VariantFields};
+use crate::input::{InputEnum, Variant, VariantBody};
 
 pub fn generate_enum_implementations(input: InputEnum) -> TokenStream {
     let enum_name = input.name();
@@ -29,7 +29,11 @@ fn generate_base_implementation(enum_name: &Ident) -> TokenStream {
 
 fn generate_variant_implementation(enum_name: &Ident, variant: &Variant) -> TokenStream {
     let variant_name = variant.name();
-    let VariantFields::Single(variant_type) = variant.body();
+
+    let variant_type = match variant.body() {
+        VariantBody::Type(ty) => ty,
+        VariantBody::None => return quote! {},
+    };
 
     quote! {
         impl<T> into_variant::IntoVariant<T> for #variant_type
