@@ -20,21 +20,22 @@ impl InputEnum {
 
 pub struct Variant {
     name: Ident,
-    body: VariantFields,
+    body: VariantBody,
 }
 
 impl Variant {
-    pub fn new(name: Ident, body: VariantFields) -> Self {
+    pub fn new(name: Ident, body: VariantBody) -> Self {
         Self { name, body }
     }
     pub fn name(&self) -> &Ident {
         &self.name
     }
-    pub fn body(&self) -> &VariantFields {
+    pub fn body(&self) -> &VariantBody {
         &self.body
     }
 }
 
-pub enum VariantFields {
-    Single(Type),
+pub enum VariantBody {
+    Type(Type),
+    None,
 }
